#ifndef DATA_CONFIG_H
#define DATA_CONFIG_H TRUE

/*
**  config.h
**
**  (C) Copyright 1998-2004 Rocklyte Systems.
**      All Rights Reserved.
*/

#ifndef MAIN_H
#include <pandora/main.h>
#endif

/*****************************************************************************
** Configuration class.
*/

#define VER_CONFIG 1.0

struct ConfigEntry {
   STRING Section;
   STRING Item;
   STRING Data;
   LONG SectionOffset;
   LONG ItemOffset;
   LONG DataOffset;
};

#define CNF_STRIPQUOTES 0x00000001
#define CNF_AUTOSAVE    0x00000002
#define CNF_LOCKRECORDS 0x00000004

/*****************************************************************************
** Config Methods
*/

#define MT_ReadConfig                -1
#define MT_ReadConfigInt             -2
#define MT_WriteConfig               -3
#define MT_DeleteConfigEntry         -4
#define MT_DeleteConfigSection       -5
#define MT_GetConfigSectionFromIndex -6
#define MT_SortConfig                -7
#define MT_ReadConfigFloat           -8
#define MT_MergeConfigFile           -9
#define MT_MergeConfig               -10
#define MT_SetConfig                 -11
#define MT_AddConfigEntry            MT_WriteConfig

struct mtAddConfigEntry {
   STRING Section;
   STRING Item;
   STRING Data;
};

struct mtDeleteConfigEntry {
   LONG Index;
};

struct mtDeleteConfigSection {
   STRING Section;
};

struct mtGetConfigSectionFromIndex {
   LONG Index;
   STRING Result;
};

struct mtMergeConfig {
   OBJECTID ConfigID;
};

struct mtMergeConfigFile {
   STRING Location;
};

struct mtReadConfigFloat {
   STRING Section;
   STRING Item;
   union {
      DOUBLE Float; /* Result */
      DOUBLE Result;
   };
};

struct mtReadConfigInt {
   STRING Section;
   STRING Item;
   union {
      LONG Integer; /* Result */
      LONG Result;
   };
};

struct mtReadConfig {
   STRING Section;
   STRING Item;
   union {
      STRING Data; /* Result */
      STRING Result;
   };
};

struct mtSetConfig {
   STRING Section;
   STRING Item;
   STRING Data;
};

struct mtSortConfig {
   STRING Item;
   LONG Descending;
};

struct mtWriteConfig {
   STRING Section;
   STRING Item;
   STRING Data;
};

static inline ERROR cfgWrite(APTR Self, STRING Section, STRING Item, STRING Data)
{
   struct mtWriteConfig write;
   write.Section = Section;
   write.Item    = Item;
   write.Data    = Data;
   return(Action(MT_WriteConfig, Self, &write));
}

static inline ERROR cfgRead(APTR Self, STRING Section, STRING Item, STRING *Value)
{
   struct mtReadConfig read;
   ERROR error;
   read.Section = Section;
   read.Item    = Item;
   error = Action(MT_ReadConfig, Self, &read);
   *Value = read.Result;
   return(error);
}

static inline ERROR cfgReadFloat(APTR Self, STRING Section, STRING Item, DOUBLE *Value)
{
   struct mtReadConfigFloat read;
   ERROR error;
   read.Section = Section;
   read.Item    = Item;
   error = Action(MT_ReadConfigFloat, Self, &read);
   *Value = read.Result;
   return(error);
}

static inline ERROR cfgReadInt(APTR Self, STRING Section, STRING Item, LONG *Value)
{
   struct mtReadConfigInt read;
   ERROR error;
   read.Section = Section;
   read.Item    = Item;
   error = Action(MT_ReadConfigInt, Self, &read);
   *Value = read.Result;
   return(error);
}

#endif /* DATA_CONFIG_H */
